diff -r 235cdce126cf javafx-ui-common/src/javafx/scene/PerspectiveCamera.java
--- a/javafx-ui-common/src/javafx/scene/PerspectiveCamera.java	Fri May 03 11:38:47 2013 -0700
+++ b/javafx-ui-common/src/javafx/scene/PerspectiveCamera.java	Fri May 03 15:59:20 2013 -0700
@@ -51,12 +51,12 @@
  * origin in the upper left corner of the panel with the Y-axis pointing
  * down and the Z axis pointing away from the viewer (into the screen). The
  * units are in pixel coordinates at the projection plane (Z=0).
- *
+ * 
  * @since JavaFX 1.3
  */
 public  class PerspectiveCamera extends Camera {   
 
-    private boolean fixedEyePosition = false;
+    private boolean manual = false;
 
     private static final Affine3D LOOK_AT_TX = new Affine3D();
     static {
@@ -129,31 +129,37 @@
     }
 
    /**
-    * Construct a PerspectiveCamera that may fix its eye position at (0, 0, 0),
-    * in its coordinate space, regardless in the change in the dimension
-    * of the projection area (or Window resize) if {@code fixedEyePosition} is true. 
+    * Construct a PerspectiveCamera with two possible camera mode, manual or non manual
+    * In the non manual mode, which is the default, the projection plane and the 
+    * device independent unit match with 2D ParallelCamera at Z=0. Resizing the 
+    * window will either see more or less of the scene. Objects in the scene will  
+    * stay at the same size. 
+    * If manual is set to true, the eye position remains fix at (0, 0, 0) in the
+    * local coordinate of the camera. Resizing the window will deduce or enlarge the scene. 
+    * The coverage of the scene remain the same, but objects in the scene will shrink
+    * or grow proportionally to the resized window.
     *
     * @since JavaFX 8
     */
-    public PerspectiveCamera(boolean fixedEyePosition) {
-        this.fixedEyePosition = fixedEyePosition;
+    public PerspectiveCamera(boolean manual) {
+        this.manual = manual;
     }
 
-    public final boolean isFixedEyePosition() {
-        return fixedEyePosition;
+    public final boolean isManual() {
+        return manual;
     }
 
     @Override
     final PickRay computePickRay(double x, double y, PickRay pickRay) {
 
-        return PickRay.computePerspectivePickRay(x, y, fixedEyePosition,
+        return PickRay.computePerspectivePickRay(x, y, manual,
                 getViewWidth(), getViewHeight(),
                 getFieldOfView(), isVerticalFieldOfView(),
                 getCameraTransform(), pickRay);
     }
 
     @Override Camera copy() {
-        PerspectiveCamera c = new PerspectiveCamera(fixedEyePosition);
+        PerspectiveCamera c = new PerspectiveCamera(manual);
         c.setNearClip(getNearClip());
         c.setFarClip(getFarClip());
         c.setFieldOfView(getFieldOfView());
@@ -167,7 +173,7 @@
     @Deprecated
     @Override
     protected PGNode impl_createPGNode() {
-        PGPerspectiveCamera pgCamera = Toolkit.getToolkit().createPGPerspectiveCamera(fixedEyePosition);    
+        PGPerspectiveCamera pgCamera = Toolkit.getToolkit().createPGPerspectiveCamera(manual);    
         pgCamera.setNearClip((float) getNearClip());
         pgCamera.setFarClip((float) getFarClip());
         pgCamera.setFieldOfView((float) getFieldOfView());
@@ -199,10 +205,10 @@
     @Override
     protected void computeViewTransform(Affine3D view) {
 
         // In the case of fixedEyePosition the camera position is (0,0,0) in
         // local coord. of the camera node. In non-fixed eye case, the camera
         // position is (w/2, h/2, h/2/tan) in local coord. of the camera.
-        if (isFixedEyePosition()) {
+        if (isManual()) {
             view.setTransform(LOOK_AT_TX);
         } else {
             final double viewWidth = getViewWidth();
@@ -232,7 +238,7 @@
             position = new Vec3d();
         }
 
-        if (fixedEyePosition) {
+        if (manual) {
             position.set(0.0, 0.0, -1.0);
         } else {
             final double halfViewWidth = getViewWidth() / 2.0;
@@ -199,10 +205,10 @@
     protected void computeViewTransform(Affine3D view) {
 
-        // In the case of fixedEyePosition the camera position is (0,0,0) in
-        // local coord. of the camera node. In non-fixed eye case, the camera
+        // In the case of manual the camera position is (0,0,0) in
+        // local coord. of the camera node. In non manual case, the camera
         // position is (w/2, h/2, h/2/tan) in local coord. of the camera.
